@@ -1,30 +1,39 @@
-# auto-converted from src/Scintilla.h at Tue Mar 10 07:01:37 2020
+# auto-converted from src/Scintilla.h at Sat Apr  4 13:09:33 2020
 package Win32::Mechanize::NotepadPlusPlus::Editor::Messages;
 
 use warnings;
 use strict;
 use Exporter 5.57 ('import');
 
-our @EXPORT = qw/%scimsg/;
-our %scimsg = (
+our @EXPORT = qw/%scimsg_dummyhash/;
+our %scimsg_dummyhash = (
     'WM_USER'                                                    => 1024,
     'ANNOTATION_BOXED'                                           => 2,
     'ANNOTATION_HIDDEN'                                          => 0,
     'ANNOTATION_INDENTED'                                        => 3,
     'ANNOTATION_STANDARD'                                        => 1,
     'CARETSTYLE_BLOCK'                                           => 2,
+    'CARETSTYLE_BLOCK_AFTER'                                     => 0x100,
+    'CARETSTYLE_INS_MASK'                                        => 0xF,
     'CARETSTYLE_INVISIBLE'                                       => 0,
     'CARETSTYLE_LINE'                                            => 1,
+    'CARETSTYLE_OVERSTRIKE_BAR'                                  => 0,
+    'CARETSTYLE_OVERSTRIKE_BLOCK'                                => 0x10,
     'CARET_EVEN'                                                 => 0x08,
     'CARET_JUMPS'                                                => 0x10,
     'CARET_SLOP'                                                 => 0x01,
     'CARET_STRICT'                                               => 0x04,
     'EDGE_BACKGROUND'                                            => 2,
     'EDGE_LINE'                                                  => 1,
+    'EDGE_MULTILINE'                                             => 3,
     'EDGE_NONE'                                                  => 0,
     'INDIC0_MASK'                                                => 0x20,
     'INDIC1_MASK'                                                => 0x40,
     'INDIC2_MASK'                                                => 0x80,
+    'INDICATOR_CONTAINER'                                        => 8,
+    'INDICATOR_IME'                                              => 32,
+    'INDICATOR_IME_MAX'                                          => 35,
+    'INDICATOR_MAX'                                              => 35,
     'INDICS_MASK'                                                => 0xE0,
     'INDIC_BOX'                                                  => 6,
     'INDIC_COMPOSITIONTHICK'                                     => 14,
@@ -35,11 +44,15 @@ our %scimsg = (
     'INDIC_DOTBOX'                                               => 12,
     'INDIC_DOTS'                                                 => 10,
     'INDIC_FULLBOX'                                              => 16,
+    'INDIC_GRADIENT'                                             => 20,
+    'INDIC_GRADIENTCENTRE'                                       => 21,
     'INDIC_HIDDEN'                                               => 5,
     'INDIC_IME'                                                  => 32,
     'INDIC_IME_MAX'                                              => 35,
     'INDIC_MAX'                                                  => 35,
     'INDIC_PLAIN'                                                => 0,
+    'INDIC_POINT'                                                => 18,
+    'INDIC_POINTCHARACTER'                                       => 19,
     'INDIC_ROUNDBOX'                                             => 7,
     'INDIC_SQUIGGLE'                                             => 1,
     'INDIC_SQUIGGLELOW'                                          => 11,
@@ -56,6 +69,7 @@ our %scimsg = (
     'SCEN_SETFOCUS'                                              => 512,
     'SCFIND_CXX11REGEX'                                          => 0x00800000,
     'SCFIND_MATCHCASE'                                           => 0x4,
+    'SCFIND_NONE'                                                => 0x0,
     'SCFIND_POSIX'                                               => 0x00400000,
     'SCFIND_REGEXP'                                              => 0x00200000,
     'SCFIND_WHOLEWORD'                                           => 0x2,
@@ -69,6 +83,7 @@ our %scimsg = (
     'SCI_ADDUNDOACTION'                                          => 2560,
     'SCI_ALLOCATE'                                               => 2446,
     'SCI_ALLOCATEEXTENDEDSTYLES'                                 => 2553,
+    'SCI_ALLOCATELINECHARACTERINDEX'                             => 2711,
     'SCI_ALLOCATESUBSTYLES'                                      => 4020,
     'SCI_ANNOTATIONCLEARALL'                                     => 2547,
     'SCI_ANNOTATIONGETLINES'                                     => 2546,
@@ -168,6 +183,7 @@ our %scimsg = (
     'SCI_COPYRANGE'                                              => 2419,
     'SCI_COPYTEXT'                                               => 2420,
     'SCI_COUNTCHARACTERS'                                        => 2633,
+    'SCI_COUNTCODEUNITS'                                         => 2715,
     'SCI_CREATEDOCUMENT'                                         => 2375,
     'SCI_CREATELOADER'                                           => 2632,
     'SCI_CUT'                                                    => 2177,
@@ -181,6 +197,7 @@ our %scimsg = (
     'SCI_DELWORDRIGHTEND'                                        => 2518,
     'SCI_DESCRIBEKEYWORDSETS'                                    => 4017,
     'SCI_DESCRIBEPROPERTY'                                       => 4016,
+    'SCI_DESCRIPTIONOFSTYLE'                                     => 4032,
     'SCI_DISTANCETOSECONDARYSTYLES'                              => 4025,
     'SCI_DOCLINEFROMVISIBLE'                                     => 2221,
     'SCI_DOCUMENTEND'                                            => 2318,
@@ -202,10 +219,13 @@ our %scimsg = (
     'SCI_FINDTEXT'                                               => 2150,
     'SCI_FOLDALL'                                                => 2662,
     'SCI_FOLDCHILDREN'                                           => 2238,
+    'SCI_FOLDDISPLAYTEXTGETSTYLE'                                => 2707,
+    'SCI_FOLDDISPLAYTEXTSETSTYLE'                                => 2701,
     'SCI_FOLDLINE'                                               => 2237,
     'SCI_FORMATRANGE'                                            => 2151,
     'SCI_FORMFEED'                                               => 2330,
     'SCI_FREESUBSTYLES'                                          => 4023,
+    'SCI_GETACCESSIBILITY'                                       => 2703,
     'SCI_GETADDITIONALCARETFORE'                                 => 2605,
     'SCI_GETADDITIONALCARETSBLINK'                               => 2568,
     'SCI_GETADDITIONALCARETSVISIBLE'                             => 2609,
@@ -215,27 +235,33 @@ our %scimsg = (
     'SCI_GETANCHOR'                                              => 2009,
     'SCI_GETAUTOMATICFOLD'                                       => 2664,
     'SCI_GETBACKSPACEUNINDENTS'                                  => 2263,
+    'SCI_GETBIDIRECTIONAL'                                       => 2708,
     'SCI_GETBUFFEREDDRAW'                                        => 2034,
     'SCI_GETCARETFORE'                                           => 2138,
     'SCI_GETCARETLINEBACK'                                       => 2097,
     'SCI_GETCARETLINEBACKALPHA'                                  => 2471,
+    'SCI_GETCARETLINEFRAME'                                      => 2704,
     'SCI_GETCARETLINEVISIBLE'                                    => 2095,
     'SCI_GETCARETLINEVISIBLEALWAYS'                              => 2654,
     'SCI_GETCARETPERIOD'                                         => 2075,
     'SCI_GETCARETSTICKY'                                         => 2457,
     'SCI_GETCARETSTYLE'                                          => 2513,
     'SCI_GETCARETWIDTH'                                          => 2189,
+    'SCI_GETCHARACTERCATEGORYOPTIMIZATION'                       => 2721,
     'SCI_GETCHARACTERPOINTER'                                    => 2520,
     'SCI_GETCHARAT'                                              => 2007,
     'SCI_GETCODEPAGE'                                            => 2137,
     'SCI_GETCOLUMN'                                              => 2129,
+    'SCI_GETCOMMANDEVENTS'                                       => 2718,
     'SCI_GETCONTROLCHARSYMBOL'                                   => 2389,
     'SCI_GETCURLINE'                                             => 2027,
     'SCI_GETCURRENTPOS'                                          => 2008,
     'SCI_GETCURSOR'                                              => 2387,
+    'SCI_GETDEFAULTFOLDDISPLAYTEXT'                              => 2723,
     'SCI_GETDIRECTFUNCTION'                                      => 2184,
     'SCI_GETDIRECTPOINTER'                                       => 2185,
     'SCI_GETDOCPOINTER'                                          => 2357,
+    'SCI_GETDOCUMENTOPTIONS'                                     => 2379,
     'SCI_GETEDGECOLOUR'                                          => 2364,
     'SCI_GETEDGECOLUMN'                                          => 2360,
     'SCI_GETEDGEMODE'                                            => 2362,
@@ -258,6 +284,7 @@ our %scimsg = (
     'SCI_GETHOTSPOTSINGLELINE'                                   => 2497,
     'SCI_GETHSCROLLBAR'                                          => 2131,
     'SCI_GETIDENTIFIER'                                          => 2623,
+    'SCI_GETIDLESTYLING'                                         => 2693,
     'SCI_GETIMEINTERACTION'                                      => 2678,
     'SCI_GETINDENT'                                              => 2123,
     'SCI_GETINDENTATIONGUIDES'                                   => 2133,
@@ -270,6 +297,7 @@ our %scimsg = (
     'SCI_GETLEXER'                                               => 4002,
     'SCI_GETLEXERLANGUAGE'                                       => 4012,
     'SCI_GETLINE'                                                => 2153,
+    'SCI_GETLINECHARACTERINDEX'                                  => 2710,
     'SCI_GETLINECOUNT'                                           => 2154,
     'SCI_GETLINEENDPOSITION'                                     => 2136,
     'SCI_GETLINEENDTYPESACTIVE'                                  => 2658,
@@ -282,11 +310,13 @@ our %scimsg = (
     'SCI_GETLINESTATE'                                           => 2093,
     'SCI_GETLINEVISIBLE'                                         => 2228,
     'SCI_GETMAINSELECTION'                                       => 2575,
+    'SCI_GETMARGINBACKN'                                         => 2251,
     'SCI_GETMARGINCURSORN'                                       => 2249,
     'SCI_GETMARGINLEFT'                                          => 2156,
     'SCI_GETMARGINMASKN'                                         => 2245,
     'SCI_GETMARGINOPTIONS'                                       => 2557,
     'SCI_GETMARGINRIGHT'                                         => 2158,
+    'SCI_GETMARGINS'                                             => 2253,
     'SCI_GETMARGINSENSITIVEN'                                    => 2247,
     'SCI_GETMARGINTYPEN'                                         => 2241,
     'SCI_GETMARGINWIDTHN'                                        => 2243,
@@ -296,8 +326,11 @@ our %scimsg = (
     'SCI_GETMOUSEDOWNCAPTURES'                                   => 2385,
     'SCI_GETMOUSEDWELLTIME'                                      => 2265,
     'SCI_GETMOUSESELECTIONRECTANGULARSWITCH'                     => 2669,
+    'SCI_GETMOUSEWHEELCAPTURES'                                  => 2697,
+    'SCI_GETMOVEEXTENDSSELECTION'                                => 2706,
     'SCI_GETMULTIPASTE'                                          => 2615,
     'SCI_GETMULTIPLESELECTION'                                   => 2564,
+    'SCI_GETNAMEDSTYLES'                                         => 4029,
     'SCI_GETNEXTTABSTOP'                                         => 2677,
     'SCI_GETOVERTYPE'                                            => 2187,
     'SCI_GETPASTECONVERTENDINGS'                                 => 2468,
@@ -345,6 +378,7 @@ our %scimsg = (
     'SCI_GETSUBSTYLEBASES'                                       => 4026,
     'SCI_GETSUBSTYLESLENGTH'                                     => 4022,
     'SCI_GETSUBSTYLESSTART'                                      => 4021,
+    'SCI_GETTABDRAWMODE'                                         => 2698,
     'SCI_GETTABINDENTS'                                          => 2261,
     'SCI_GETTABWIDTH'                                            => 2121,
     'SCI_GETTAG'                                                 => 2616,
@@ -357,7 +391,6 @@ our %scimsg = (
     'SCI_GETTEXTRANGE'                                           => 2162,
     'SCI_GETTWOPHASEDRAW'                                        => 2283,
     'SCI_GETUNDOCOLLECTION'                                      => 2019,
-    'SCI_GETUSEPALETTE'                                          => 2139,
     'SCI_GETUSETABS'                                             => 2125,
     'SCI_GETVIEWEOL'                                             => 2355,
     'SCI_GETVIEWWS'                                              => 2020,
@@ -385,6 +418,7 @@ our %scimsg = (
     'SCI_HOMERECTEXTEND'                                         => 2430,
     'SCI_HOMEWRAP'                                               => 2349,
     'SCI_HOMEWRAPEXTEND'                                         => 2450,
+    'SCI_INDEXPOSITIONFROMLINE'                                  => 2714,
     'SCI_INDICATORALLONFOR'                                      => 2506,
     'SCI_INDICATORCLEARRANGE'                                    => 2505,
     'SCI_INDICATOREND'                                           => 2509,
@@ -408,6 +442,7 @@ our %scimsg = (
     'SCI_INDICSETSTYLE'                                          => 2080,
     'SCI_INDICSETUNDER'                                          => 2510,
     'SCI_INSERTTEXT'                                             => 2003,
+    'SCI_ISRANGEWORD'                                            => 2691,
     'SCI_LEXER_START'                                            => 4000,
     'SCI_LINECOPY'                                               => 2455,
     'SCI_LINECUT'                                                => 2337,
@@ -423,8 +458,10 @@ our %scimsg = (
     'SCI_LINEENDRECTEXTEND'                                      => 2432,
     'SCI_LINEENDWRAP'                                            => 2451,
     'SCI_LINEENDWRAPEXTEND'                                      => 2452,
+    'SCI_LINEFROMINDEXPOSITION'                                  => 2713,
     'SCI_LINEFROMPOSITION'                                       => 2166,
     'SCI_LINELENGTH'                                             => 2350,
+    'SCI_LINEREVERSE'                                            => 2354,
     'SCI_LINESCROLL'                                             => 2168,
     'SCI_LINESCROLLDOWN'                                         => 2342,
     'SCI_LINESCROLLUP'                                           => 2343,
@@ -467,6 +504,11 @@ our %scimsg = (
     'SCI_MOVECARETINSIDEVIEW'                                    => 2401,
     'SCI_MOVESELECTEDLINESDOWN'                                  => 2621,
     'SCI_MOVESELECTEDLINESUP'                                    => 2620,
+    'SCI_MULTIEDGEADDLINE'                                       => 2694,
+    'SCI_MULTIEDGECLEARALL'                                      => 2695,
+    'SCI_MULTIPLESELECTADDEACH'                                  => 2689,
+    'SCI_MULTIPLESELECTADDNEXT'                                  => 2688,
+    'SCI_NAMEOFSTYLE'                                            => 4030,
     'SCI_NEWLINE'                                                => 2329,
     'SCI_NULL'                                                   => 2172,
     'SCI_OPTIONAL_START'                                         => 3000,
@@ -489,6 +531,7 @@ our %scimsg = (
     'SCI_POSITIONFROMPOINT'                                      => 2022,
     'SCI_POSITIONFROMPOINTCLOSE'                                 => 2023,
     'SCI_POSITIONRELATIVE'                                       => 2670,
+    'SCI_POSITIONRELATIVECODEUNITS'                              => 2716,
     'SCI_PRIVATELEXERCALL'                                       => 4013,
     'SCI_PROPERTYNAMES'                                          => 4014,
     'SCI_PROPERTYTYPE'                                           => 4015,
@@ -497,6 +540,7 @@ our %scimsg = (
     'SCI_REGISTERRGBAIMAGE'                                      => 2627,
     'SCI_RELEASEALLEXTENDEDSTYLES'                               => 2552,
     'SCI_RELEASEDOCUMENT'                                        => 2377,
+    'SCI_RELEASELINECHARACTERINDEX'                              => 2712,
     'SCI_REPLACESEL'                                             => 2170,
     'SCI_REPLACETARGET'                                          => 2194,
     'SCI_REPLACETARGETRE'                                        => 2195,
@@ -515,6 +559,7 @@ our %scimsg = (
     'SCI_SELECTALL'                                              => 2013,
     'SCI_SELECTIONDUPLICATE'                                     => 2469,
     'SCI_SELECTIONISRECTANGLE'                                   => 2372,
+    'SCI_SETACCESSIBILITY'                                       => 2702,
     'SCI_SETADDITIONALCARETFORE'                                 => 2604,
     'SCI_SETADDITIONALCARETSBLINK'                               => 2567,
     'SCI_SETADDITIONALCARETSVISIBLE'                             => 2608,
@@ -525,21 +570,26 @@ our %scimsg = (
     'SCI_SETANCHOR'                                              => 2026,
     'SCI_SETAUTOMATICFOLD'                                       => 2663,
     'SCI_SETBACKSPACEUNINDENTS'                                  => 2262,
+    'SCI_SETBIDIRECTIONAL'                                       => 2709,
     'SCI_SETBUFFEREDDRAW'                                        => 2035,
     'SCI_SETCARETFORE'                                           => 2069,
     'SCI_SETCARETLINEBACK'                                       => 2098,
     'SCI_SETCARETLINEBACKALPHA'                                  => 2470,
+    'SCI_SETCARETLINEFRAME'                                      => 2705,
     'SCI_SETCARETLINEVISIBLE'                                    => 2096,
     'SCI_SETCARETLINEVISIBLEALWAYS'                              => 2655,
     'SCI_SETCARETPERIOD'                                         => 2076,
     'SCI_SETCARETSTICKY'                                         => 2458,
     'SCI_SETCARETSTYLE'                                          => 2512,
     'SCI_SETCARETWIDTH'                                          => 2188,
+    'SCI_SETCHARACTERCATEGORYOPTIMIZATION'                       => 2720,
     'SCI_SETCHARSDEFAULT'                                        => 2444,
     'SCI_SETCODEPAGE'                                            => 2037,
+    'SCI_SETCOMMANDEVENTS'                                       => 2717,
     'SCI_SETCONTROLCHARSYMBOL'                                   => 2388,
     'SCI_SETCURRENTPOS'                                          => 2141,
     'SCI_SETCURSOR'                                              => 2386,
+    'SCI_SETDEFAULTFOLDDISPLAYTEXT'                              => 2722,
     'SCI_SETDOCPOINTER'                                          => 2358,
     'SCI_SETEDGECOLOUR'                                          => 2365,
     'SCI_SETEDGECOLUMN'                                          => 2361,
@@ -565,6 +615,7 @@ our %scimsg = (
     'SCI_SETHSCROLLBAR'                                          => 2130,
     'SCI_SETIDENTIFIER'                                          => 2622,
     'SCI_SETIDENTIFIERS'                                         => 4024,
+    'SCI_SETIDLESTYLING'                                         => 2692,
     'SCI_SETIMEINTERACTION'                                      => 2679,
     'SCI_SETINDENT'                                              => 2122,
     'SCI_SETINDENTATIONGUIDES'                                   => 2132,
@@ -580,11 +631,13 @@ our %scimsg = (
     'SCI_SETLINEINDENTATION'                                     => 2126,
     'SCI_SETLINESTATE'                                           => 2092,
     'SCI_SETMAINSELECTION'                                       => 2574,
+    'SCI_SETMARGINBACKN'                                         => 2250,
     'SCI_SETMARGINCURSORN'                                       => 2248,
     'SCI_SETMARGINLEFT'                                          => 2155,
     'SCI_SETMARGINMASKN'                                         => 2244,
     'SCI_SETMARGINOPTIONS'                                       => 2539,
     'SCI_SETMARGINRIGHT'                                         => 2157,
+    'SCI_SETMARGINS'                                             => 2252,
     'SCI_SETMARGINSENSITIVEN'                                    => 2246,
     'SCI_SETMARGINTYPEN'                                         => 2240,
     'SCI_SETMARGINWIDTHN'                                        => 2242,
@@ -592,6 +645,7 @@ our %scimsg = (
     'SCI_SETMOUSEDOWNCAPTURES'                                   => 2384,
     'SCI_SETMOUSEDWELLTIME'                                      => 2264,
     'SCI_SETMOUSESELECTIONRECTANGULARSWITCH'                     => 2668,
+    'SCI_SETMOUSEWHEELCAPTURES'                                  => 2696,
     'SCI_SETMULTIPASTE'                                          => 2614,
     'SCI_SETMULTIPLESELECTION'                                   => 2563,
     'SCI_SETOVERTYPE'                                            => 2186,
@@ -633,6 +687,7 @@ our %scimsg = (
     'SCI_SETSTYLEBITS'                                           => 2090,
     'SCI_SETSTYLING'                                             => 2033,
     'SCI_SETSTYLINGEX'                                           => 2073,
+    'SCI_SETTABDRAWMODE'                                         => 2699,
     'SCI_SETTABINDENTS'                                          => 2260,
     'SCI_SETTABWIDTH'                                            => 2036,
     'SCI_SETTARGETEND'                                           => 2192,
@@ -642,7 +697,6 @@ our %scimsg = (
     'SCI_SETTEXT'                                                => 2181,
     'SCI_SETTWOPHASEDRAW'                                        => 2284,
     'SCI_SETUNDOCOLLECTION'                                      => 2012,
-    'SCI_SETUSEPALETTE'                                          => 2039,
     'SCI_SETUSETABS'                                             => 2124,
     'SCI_SETVIEWEOL'                                             => 2356,
     'SCI_SETVIEWWS'                                              => 2021,
@@ -706,12 +760,15 @@ our %scimsg = (
     'SCI_STYLESETWEIGHT'                                         => 2063,
     'SCI_SWAPMAINANCHORCARET'                                    => 2607,
     'SCI_TAB'                                                    => 2327,
+    'SCI_TAGSOFSTYLE'                                            => 4031,
     'SCI_TARGETASUTF8'                                           => 2447,
     'SCI_TARGETFROMSELECTION'                                    => 2287,
+    'SCI_TARGETWHOLEDOCUMENT'                                    => 2690,
     'SCI_TEXTHEIGHT'                                             => 2279,
     'SCI_TEXTWIDTH'                                              => 2276,
     'SCI_TOGGLECARETSTICKY'                                      => 2459,
     'SCI_TOGGLEFOLD'                                             => 2231,
+    'SCI_TOGGLEFOLDSHOWTEXT'                                     => 2700,
     'SCI_UNDO'                                                   => 2176,
     'SCI_UPPERCASE'                                              => 2341,
     'SCI_USEPOPUP'                                               => 2371,
@@ -770,7 +827,9 @@ our %scimsg = (
     'SCMOD_SUPER'                                                => 8,
     'SCN_AUTOCCANCELLED'                                         => 2025,
     'SCN_AUTOCCHARDELETED'                                       => 2026,
+    'SCN_AUTOCCOMPLETED'                                         => 2030,
     'SCN_AUTOCSELECTION'                                         => 2022,
+    'SCN_AUTOCSELECTIONCHANGE'                                   => 2032,
     'SCN_CALLTIPCLICK'                                           => 2021,
     'SCN_CHARADDED'                                              => 2001,
     'SCN_DOUBLECLICK'                                            => 2006,
@@ -787,6 +846,7 @@ our %scimsg = (
     'SCN_KEY'                                                    => 2005,
     'SCN_MACRORECORD'                                            => 2009,
     'SCN_MARGINCLICK'                                            => 2010,
+    'SCN_MARGINRIGHTCLICK'                                       => 2031,
     'SCN_MODIFIED'                                               => 2008,
     'SCN_MODIFYATTEMPTRO'                                        => 2004,
     'SCN_NEEDSHOWN'                                              => 2011,
@@ -799,18 +859,32 @@ our %scimsg = (
     'SCN_URIDROPPED'                                             => 2015,
     'SCN_USERLISTSELECTION'                                      => 2014,
     'SCN_ZOOM'                                                   => 2018,
+    'SCTD_LONGARROW'                                             => 0,
+    'SCTD_STRIKEOUT'                                             => 1,
     'SCVS_NONE'                                                  => 0,
+    'SCVS_NOWRAPLINESTART'                                       => 4,
     'SCVS_RECTANGULARSELECTION'                                  => 1,
     'SCVS_USERACCESSIBLE'                                        => 2,
     'SCWS_INVISIBLE'                                             => 0,
     'SCWS_VISIBLEAFTERINDENT'                                    => 2,
     'SCWS_VISIBLEALWAYS'                                         => 1,
+    'SCWS_VISIBLEONLYININDENT'                                   => 3,
+    'SC_ACCESSIBILITY_DISABLED'                                  => 0,
+    'SC_ACCESSIBILITY_ENABLED'                                   => 1,
+    'SC_AC_COMMAND'                                              => 5,
+    'SC_AC_DOUBLECLICK'                                          => 2,
+    'SC_AC_FILLUP'                                               => 1,
+    'SC_AC_NEWLINE'                                              => 4,
+    'SC_AC_TAB'                                                  => 3,
     'SC_ALPHA_NOALPHA'                                           => 256,
     'SC_ALPHA_OPAQUE'                                            => 255,
     'SC_ALPHA_TRANSPARENT'                                       => 0,
     'SC_AUTOMATICFOLD_CHANGE'                                    => 0x0004,
     'SC_AUTOMATICFOLD_CLICK'                                     => 0x0002,
     'SC_AUTOMATICFOLD_SHOW'                                      => 0x0001,
+    'SC_BIDIRECTIONAL_DISABLED'                                  => 0,
+    'SC_BIDIRECTIONAL_L2R'                                       => 1,
+    'SC_BIDIRECTIONAL_R2L'                                       => 2,
     'SC_CACHE_CARET'                                             => 1,
     'SC_CACHE_DOCUMENT'                                          => 3,
     'SC_CACHE_NONE'                                              => 0,
@@ -820,9 +894,13 @@ our %scimsg = (
     'SC_CARETSTICKY_WHITESPACE'                                  => 2,
     'SC_CASEINSENSITIVEBEHAVIOUR_IGNORECASE'                     => 1,
     'SC_CASEINSENSITIVEBEHAVIOUR_RESPECTCASE'                    => 0,
+    'SC_CASE_CAMEL'                                              => 3,
     'SC_CASE_LOWER'                                              => 2,
     'SC_CASE_MIXED'                                              => 0,
     'SC_CASE_UPPER'                                              => 1,
+    'SC_CHARACTERSOURCE_DIRECT_INPUT'                            => 0,
+    'SC_CHARACTERSOURCE_IME_RESULT'                              => 2,
+    'SC_CHARACTERSOURCE_TENTATIVE_INPUT'                         => 1,
     'SC_CHARSET_8859_15'                                         => 1000,
     'SC_CHARSET_ANSI'                                            => 0,
     'SC_CHARSET_ARABIC'                                          => 178,
@@ -838,18 +916,21 @@ our %scimsg = (
     'SC_CHARSET_JOHAB'                                           => 130,
     'SC_CHARSET_MAC'                                             => 77,
     'SC_CHARSET_OEM'                                             => 255,
+    'SC_CHARSET_OEM866'                                          => 866,
     'SC_CHARSET_RUSSIAN'                                         => 204,
     'SC_CHARSET_SHIFTJIS'                                        => 128,
     'SC_CHARSET_SYMBOL'                                          => 2,
     'SC_CHARSET_THAI'                                            => 222,
     'SC_CHARSET_TURKISH'                                         => 162,
     'SC_CHARSET_VIETNAMESE'                                      => 163,
-    'SC_CP_DBCS'                                                 => 1,
     'SC_CP_UTF8'                                                 => 65001,
     'SC_CURSORARROW'                                             => 2,
     'SC_CURSORNORMAL'                                            => -1,
     'SC_CURSORREVERSEARROW'                                      => 7,
     'SC_CURSORWAIT'                                              => 4,
+    'SC_DOCUMENTOPTION_DEFAULT'                                  => 0,
+    'SC_DOCUMENTOPTION_STYLES_NONE'                              => 0x1,
+    'SC_DOCUMENTOPTION_TEXT_LARGE'                               => 0x100,
     'SC_EFF_QUALITY_ANTIALIASED'                                 => 2,
     'SC_EFF_QUALITY_DEFAULT'                                     => 0,
     'SC_EFF_QUALITY_LCD_OPTIMIZED'                               => 3,
@@ -861,6 +942,9 @@ our %scimsg = (
     'SC_FOLDACTION_CONTRACT'                                     => 0,
     'SC_FOLDACTION_EXPAND'                                       => 1,
     'SC_FOLDACTION_TOGGLE'                                       => 2,
+    'SC_FOLDDISPLAYTEXT_BOXED'                                   => 2,
+    'SC_FOLDDISPLAYTEXT_HIDDEN'                                  => 0,
+    'SC_FOLDDISPLAYTEXT_STANDARD'                                => 1,
     'SC_FOLDFLAG_LEVELNUMBERS'                                   => 0x0040,
     'SC_FOLDFLAG_LINEAFTER_CONTRACTED'                           => 0x0010,
     'SC_FOLDFLAG_LINEAFTER_EXPANDED'                             => 0x0008,
@@ -872,6 +956,10 @@ our %scimsg = (
     'SC_FOLDLEVELNUMBERMASK'                                     => 0x0FFF,
     'SC_FOLDLEVELWHITEFLAG'                                      => 0x1000,
     'SC_FONT_SIZE_MULTIPLIER'                                    => 100,
+    'SC_IDLESTYLING_AFTERVISIBLE'                                => 2,
+    'SC_IDLESTYLING_ALL'                                         => 3,
+    'SC_IDLESTYLING_NONE'                                        => 0,
+    'SC_IDLESTYLING_TOVISIBLE'                                   => 1,
     'SC_IME_INLINE'                                              => 1,
     'SC_IME_WINDOWED'                                            => 0,
     'SC_INDICFLAG_VALUEFORE'                                     => 1,
@@ -882,11 +970,15 @@ our %scimsg = (
     'SC_IV_NONE'                                                 => 0,
     'SC_IV_REAL'                                                 => 1,
     'SC_LASTSTEPINUNDOREDO'                                      => 0x100,
+    'SC_LINECHARACTERINDEX_NONE'                                 => 0,
+    'SC_LINECHARACTERINDEX_UTF16'                                => 2,
+    'SC_LINECHARACTERINDEX_UTF32'                                => 1,
     'SC_LINE_END_TYPE_DEFAULT'                                   => 0,
     'SC_LINE_END_TYPE_UNICODE'                                   => 1,
     'SC_MARGINOPTION_NONE'                                       => 0,
     'SC_MARGINOPTION_SUBLINESELECT'                              => 1,
     'SC_MARGIN_BACK'                                             => 2,
+    'SC_MARGIN_COLOUR'                                           => 6,
     'SC_MARGIN_FORE'                                             => 3,
     'SC_MARGIN_NUMBER'                                           => 1,
     'SC_MARGIN_RTEXT'                                            => 5,
@@ -931,6 +1023,7 @@ our %scimsg = (
     'SC_MARK_TCORNER'                                            => 11,
     'SC_MARK_TCORNERCURVE'                                       => 17,
     'SC_MARK_UNDERLINE'                                          => 29,
+    'SC_MARK_VERTICALBOOKMARK'                                   => 32,
     'SC_MARK_VLINE'                                              => 9,
     'SC_MASK_FOLDERS'                                            => 0xFE000000,
     'SC_MAX_MARGIN'                                              => 4,
@@ -950,6 +1043,7 @@ our %scimsg = (
     'SC_MOD_INSERTCHECK'                                         => 0x100000,
     'SC_MOD_INSERTTEXT'                                          => 0x1,
     'SC_MOD_LEXERSTATE'                                          => 0x80000,
+    'SC_MOD_NONE'                                                => 0x0,
     'SC_MULTIAUTOC_EACH'                                         => 1,
     'SC_MULTIAUTOC_ONCE'                                         => 0,
     'SC_MULTILINEUNDOREDO'                                       => 0x1000,
@@ -965,11 +1059,15 @@ our %scimsg = (
     'SC_PHASES_MULTIPLE'                                         => 2,
     'SC_PHASES_ONE'                                              => 0,
     'SC_PHASES_TWO'                                              => 1,
+    'SC_POPUP_ALL'                                               => 1,
+    'SC_POPUP_NEVER'                                             => 0,
+    'SC_POPUP_TEXT'                                              => 2,
     'SC_PRINT_BLACKONWHITE'                                      => 2,
     'SC_PRINT_COLOURONWHITE'                                     => 3,
     'SC_PRINT_COLOURONWHITEDEFAULTBG'                            => 4,
     'SC_PRINT_INVERTLIGHT'                                       => 1,
     'SC_PRINT_NORMAL'                                            => 0,
+    'SC_PRINT_SCREENCOLOURS'                                     => 5,
     'SC_SEARCHRESULT_LINEBUFFERMAXLENGTH'                        => 1024,
     'SC_SEL_LINES'                                               => 2,
     'SC_SEL_RECTANGLE'                                           => 1,
@@ -996,6 +1094,7 @@ our %scimsg = (
     'SC_WEIGHT_BOLD'                                             => 700,
     'SC_WEIGHT_NORMAL'                                           => 400,
     'SC_WEIGHT_SEMIBOLD'                                         => 600,
+    'SC_WRAPINDENT_DEEPINDENT'                                   => 3,
     'SC_WRAPINDENT_FIXED'                                        => 0,
     'SC_WRAPINDENT_INDENT'                                       => 2,
     'SC_WRAPINDENT_SAME'                                         => 1,
@@ -1015,11 +1114,13 @@ our %scimsg = (
     'STYLE_CALLTIP'                                              => 38,
     'STYLE_CONTROLCHAR'                                          => 36,
     'STYLE_DEFAULT'                                              => 32,
+    'STYLE_FOLDDISPLAYTEXT'                                      => 39,
     'STYLE_INDENTGUIDE'                                          => 37,
     'STYLE_LASTPREDEFINED'                                       => 39,
     'STYLE_LINENUMBER'                                           => 33,
     'STYLE_MAX'                                                  => 255,
     'UNDO_MAY_COALESCE'                                          => 1,
+    'UNDO_NONE'                                                  => 0,
     'VISIBLE_SLOP'                                               => 0x01,
     'VISIBLE_STRICT'                                             => 0x04,
 );
