@@ -26,8 +26,7 @@
 // Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
 
-#ifndef MENUCMDID_H
-#define MENUCMDID_H
+#pragma once
 
 #define    IDM    40000
 
@@ -522,7 +521,8 @@
 
     #define    IDM_LANG_USER               (IDM_LANG + 180)     //46180: Used for translation
     #define    IDM_LANG_USER_LIMIT         (IDM_LANG + 210)     //46210: Ajust with IDM_LANG_USER
-    #define    IDM_LANG_USER_DLG           (IDM_LANG + 250)     //46250: Used for translation 
+    #define    IDM_LANG_USER_DLG           (IDM_LANG + 250)     //46250: Used for translation
+    #define    IDM_LANG_OPENUDLDIR         (IDM_LANG + 300)
 
 
     
@@ -530,7 +530,7 @@
 #define    IDM_ABOUT    (IDM  + 7000)
     #define    IDM_HOMESWEETHOME    (IDM_ABOUT  + 1)
     #define    IDM_PROJECTPAGE      (IDM_ABOUT  + 2)
-    #define    IDM_ONLINEHELP       (IDM_ABOUT  + 3)
+    #define    IDM_ONLINEDOCUMENT   (IDM_ABOUT  + 3)
     #define    IDM_FORUM            (IDM_ABOUT  + 4)
     //#define    IDM_PLUGINSHOME      (IDM_ABOUT  + 5)
     #define    IDM_UPDATE_NPP       (IDM_ABOUT  + 6)
@@ -575,5 +575,3 @@
     #define IDM_SYSTRAYPOPUP_NEW_AND_PASTE    (IDM_SYSTRAYPOPUP + 3)
     #define IDM_SYSTRAYPOPUP_OPENFILE         (IDM_SYSTRAYPOPUP + 4)
     #define IDM_SYSTRAYPOPUP_CLOSE            (IDM_SYSTRAYPOPUP + 5)
-
-#endif //MENUCMDID_H
